@@ -70,6 +70,8 @@ $events_smarty = array();
 if (count($events) != 0)
 {
 	$eventsurlprefix = $this->GetPreference('urlprefix', 'events');
+	if (empty($eventsurlprefix))
+		$eventsurlprefix = 'events';
 	$registrationurlprefix = $this->GetPreference('registerurlprefix', 'register');
 	
 	foreach ($events as &$event)
