@@ -26,7 +26,5 @@ switch($current_version)
 }
 
 // put mention into the admin log
-$this->Audit( 0, 
-	      $this->Lang('friendlyname'), 
-	      $this->Lang('upgraded', $this->GetVersion()));
+$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('upgraded', $this->GetVersion()));
 ?>
\ No newline at end of file
